function [buttladd]=buttladd(n,rs,rl,wc);
% buttladd
% buttladd(n,rs,rl,wc) calculates ladder filter
% elements for an 'n'th order Butterworth filter 
% with load resistance 'rl', source resistance 
% 'rs' and angular 3dB cut-off frequency 'wc'.
% The result is given as a column vector with
% first element value being the series inductor
% at the source side.
% Ref:
% Wai-Kai Chen, "Passive and Active Filters -
% theory and implementations", Wiley, 1986.

% 1997-03-07 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997. All rights reserved
%
% 1998-01-26 - changed explaining text above



if rl>rs
	alfa=(1-2/((rl/rs)+1))^(1/n);
else
	alfa=(1-2/((rs/rl)+1))^(1/n);
end


element(1,1)=2*rs*sin(pi/(2*n))/((1-alfa)*wc);

for m=1:1:floor((n-1)/2),
	gamma4mm3=(4*m-3)*pi/(2*n);
	gamma4mm1=(4*m-1)*pi/(2*n);
	gamma4mm2=(4*m-2)*pi/(2*n);
	element(2*m,1)=4*sin(gamma4mm3)*sin(gamma4mm1)/(wc^2*element(2*m-1,1)...
		*(1-2*alfa*cos(gamma4mm2)+alfa^2));
	gamma4mm1=(4*m-1)*pi/(2*n);
	gamma4m=4*m*pi/(2*n);
	gamma4mp1=(4*m+1)*pi/(2*n);
	element(2*m+1,1)=4*sin(gamma4mm1)*sin(gamma4mp1)/(wc^2*element(2*m,1)...
		*(1-2*alfa*cos(gamma4m)+alfa^2));
end

% if even - add final element
if floor(n/2)==n/2
	element(n,1)=2*sin(pi/(2*n))/(rl*(1+alfa)*wc);
end

buttladd=element;