% Functions for Graphics
%
% * help <function name> for more information.
%
% General Functions
%
%  drawci      - Draws a circle.
%  drawarc     - Draws an arc.
%  drawarh     - Draws an arrow head
%  drawarw     - Draws an arrow head with tail
%  drawdot     - Draws a dot (filled circle)
%  drawrad     - Draws a radial line from the origin
%  drawarhc    - Draws arrow heads along a path defined by given data
%  drawam      - Draws radial lines, arcs and arrow heads to show
%                an angle measurement.
%
%  makearc     - Creates complex-valued points for an arc
%  makeci      - Creates complex-valued points for a circle
%
%  plotxt      - Similar to the built-in plot function but accepts
%                more attributes.
%  plotc       - Similar to plotxt but accepts complex-valued data
%                for plotting in the complex plane.
%
%  fillbox     - fills a rectangular area with specified color
%
%  xychart     - Script for generating publication quality plots.
%                Allows you to control virtually all attributes
%                by altering the contents of a copy of this file.
%
%
% Postscript
%
%  It is possible to generate Postscript code that is inserted
%  in a template file that for example might contain some kind
%  of background like a Smith-chart. All drawxxx (incl plotxt
%  and plotc) functions except those dealing with text are
%  supported. However, some attributes like colors are not
%  supported.
%
%  psbegin     - Begins a Postscript collection session
%  psend       - Ends a Postscript collection session
%
%  Low-level functions that are used by drawxxx function when
%  a Postscript collection session is active (usually not used directly).
%
%  pspatch     - Generates Postscript code for a patch
%  psdash      - Sets dash properties for line objects
%  psplotxt    - Generates Postscript code for paths (curves)
%
%
% Functions specific for the Smith chart
%
%  smtool      - Creates an impedance Smith-chart window with reading
%                and collect functions. Any kind of drawing commands
%                can be directed to the Smith-chart.  
%
%  smval       - Returns the latest "Collect"-result from the smtool
%                window.
%
%  smnewz      - Creates an impedance Smith-chart window without any
%                additional functions.
%  smnewy      - Creates an admittance Smith-chart window without any
%                additional functions.
%
%  smnew       - Low-level function for smnewy, smnewz and smtool. 
%
%  drawisoq    - Draws a constant-Q line in the Smith-chart
%
%  drawrci     - Draws a constant-resistance circle.
%  drawxci     - Draws a constant-reactance circle.
%  drawgci     - Draws a constant-conductance circle.
%  drawbci     - Draws a constant-susceptance circle.
%
%  drawrlbl    - Draws constant-resistance labels.
%  drawxlbl    - Draws constant-reactance labels.
%  drawglbl    - Draws constant-conductance labels.
%  drawblbl    - Draws constant-susceptance labels.
%
%  drawrarc    - Draws a constant-resistance arc.
%  drawxarc    - Draws a constant-reactance arc.
%  drawgarc    - Draws a constant-conductance arc.
%  drawbarc    - Draws a constant-susceptance arc.
%
%  makerarc    - Creates complex-valued points for a constant-resistance arc.
%  makexarc    - Creates complex-valued points for a constant-reactance arc.
%  makegarc    - Creates complex-valued points for a constant-conductance arc.
%  makebarc    - Creates complex-valued points for a constant-susceptance arc.

% 1999-08-30 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997-1999. All rights reserved.
