function [drawarh]=drawarh(tippos,aangle,arhspec,arhcolor);
% drawarh
% drawarh(tippos,aangle,arhspec,arhcolor);
% Draws one or several arrow heads
%
% Parameters (column vector in case of multiple arrows):
% tippos - tip position given as complex number
% aangle - angle of arrow head in degrees - zero degrees == ->
%
% Optional:
% arhspec - row matrix [baseangle,tipangle,len]
%      baseangle - in degrees
%      tipangle - in degrees
%      len - length of arrow head (assumes a quadratic space)
%  ex. [70,16,1]
% arhcolor - [R,G,B]
% 
% drawarh returns a handle to the objects drawn. In case of
% multiple arrow heads a vertical vector is returned containing the
% handles.


% 1996-12-18 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.


% Global variables for parameters that are not specified
global daelibinitialized
global daearhspec
global daefillcolor
global daepscollectactive

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==2,
	arhspec=daearhspec;
	arhcolor=daefillcolor;
else
	if nargin<4 arhcolor=daefillcolor; end
end

% Number of arrow heads
c=length(tippos);

% storage for handles
h=zeros(c,1);

if c==1,
	baseangle=pi*arhspec(1,1)/180;
	tipangle=pi*arhspec(1,2)/180;
	len=arhspec(1,3);
	d=len*[0;-cos(tipangle/2)+i*sin(tipangle/2);-cos(tipangle/2)+sin(tipangle/2)*cos(baseangle);...
		-cos(tipangle/2)-i*sin(tipangle/2);0];
	
	d=rotatec(d,aangle)+tippos;
	h(1,1)=patch(real(d),imag(d),'w');
	set(h(1,1),'facecolor',arhcolor);
	set(h(1,1),'Linewidth',0.001,'EdgeColor',get(h(1,1),'facecolor'));

	if daepscollectactive==1
		pspatch(real(d),imag(d),arhcolor);
	end

else
	cc=size(arhspec);
	if cc(1,1)==1,
		arhspec=ones(c,1)*arhspec;
	end

	cc=size(arhcolor);
	if cc(1,1)==1,
		arhcolor=ones(c,1)*arhcolor;
	end
	
	for k=1:c,
		baseangle=pi*arhspec(k,1)/180;
		tipangle=pi*arhspec(k,2)/180;
		len=arhspec(k,3);
		d=len*[0;-cos(tipangle/2)+i*sin(tipangle/2);-cos(tipangle/2)+sin(tipangle/2)*cos(baseangle);...
		-cos(tipangle/2)-i*sin(tipangle/2);0];
	
		d=tippos(k,1)+rotatec(d,aangle(k,1));
		h(k,1)=patch(real(d),imag(d),'w');
		set(h(k,1),'facecolor',arhcolor(k,:));
		set(h(k,1),'Linewidth',0.001,'EdgeColor',get(h(k,1),'facecolor'));
			if daepscollectactive==1
				pspatch(real(d),imag(d),arhcolor(k,:));
			end

	end
end

drawarh=h;

