function [drawarhc]=drawarhc(d,loc,arhspec,arhcolor);
% drawarhc
% drawarhc(d,loc,arhspec,arhcolor);
% Draws arrow heads along a path define by the complex-valued
% column vector.
%
% Parameters:
% d - [d1;d2;d3;...]
% loc -
%	'e' = ---->
%	'b' = <----
%	'm' = -->--
%	'mr'= --<--
%      all of these can be used at the same time, ie, 'ebmr'
%	 - OR -
%	a number between 0 and 1 that gives the relative placement of one
%	arrow head. Note that the number relates to the position in "d" and
%	not the relative distance along the path defined by "d".
%	- OR -
%	an integer number (>1) corresponding to the position in "d". 
%  - OR -
%  a negative loc-value will have the same effect but with the arrowhead
%  in the opposite direction.
%
% Optional:
% arhspec - row matrix [baseangle,tipangle,len]
%      baseangle - in degrees
%      tipangle - in degrees
%      len - length of arrow head (assumes a quadratic space)
%  ex. [70,16,1]
% arhcolor - [R,G,B]
% 
% drawarhc returns a handle to the object drawn. In case of multiple
% arrow heads a vertical vector is returned containing the
% handles.


% 1996-12-20 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996-98. All rights reserved.

% 1998-08-07 - added more option to control position of harrowhead/LSu


% Global variables for parameters that are not specified
global daelibinitialized
global daearhspec
global daefillcolor

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==2,
	arhspec=daearhspec;
	arhcolor=daefillcolor;
else
	if nargin<7 arhcolor=daefillcolor; end
end

% Number of arrow heads
c=length(loc);

% storage for handles
h=zeros(c,1);

% Length of data
n=length(d);

k=1;

if isstr(loc),
	if isempty(findstr(loc,'e'))==0,
		h(k,1)=drawarh(d(n,1),180*angle(d(n,1)-d(n-1,1))/pi,arhspec,arhcolor);
		k=k+1;
	end

	if isempty(findstr(loc,'b'))==0,
		h(k,1)=drawarh(d(1,1),180*angle(d(1,1)-d(2,1))/pi,arhspec,arhcolor);
		k=k+1;
	end

	if isempty(findstr(loc,'m'))==0,

	   if isempty(findstr(loc,'r'))==0,
			h(k,1)=drawarh(d(ceil(n/2),1),180*angle(d(ceil(n/2),1)-d(ceil(n/2)+1,1))/pi,...
         arhspec,arhcolor);

   	else

			h(k,1)=drawarh(d(ceil(n/2),1),180*angle(d(ceil(n/2),1)-d(ceil(n/2)-1,1))/pi,...
         arhspec,arhcolor);

   	end

  	end
      

     

  else

     

     if loc<0,

        

        loc=-loc;

        

        if loc<=1           

           rr=ceil(loc*n);          

           h(k,1)=drawarh(d(rr,1),180*angle(d(rr,1)-d(rr+1,1))/pi,arhspec,arhcolor);          

        else           

           h(k,1)=drawarh(d(loc,1),180*angle(d(loc,1)-d(loc+1,1))/pi,arhspec,arhcolor);           

        end



     else
        

        if loc<=1,           

           rr=ceil(loc*n);          

           h(k,1)=drawarh(d(rr,1),180*angle(d(rr,1)-d(rr-1,1))/pi,arhspec,arhcolor);          

        else           

           h(k,1)=drawarh(d(loc,1),180*angle(d(loc,1)-d(loc-1,1))/pi,arhspec,arhcolor);           

        end

              

     end

end

drawarhc=h;
