function [drawisoq]=drawisoq(q,linewidth,linestyle,linecolor,markersize);
% drawisoq
% drawisoq(q,linewidth,linestyle,linecolor,markersize)
% draws any number of constant-Q (quality factor)
% lines in the current figure. If multiple lines are to
% be drawn the q-values should appear in a vertical
% vector: [q1;q2;q3...].
%
% Optional:
% linewidth - in 1/72 inch (points)
% linestyle - MATLAB parameter Ex. '-', '-.' etc
% linecolor - [R,G,B]
% markersize - in 1/72 inch (points)
%
% drawisoq returns a handle to the line objects drawn. In case of
% multiple lines a vertical vector is returned containing the
% handles.

% 1997-01-21 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997. All rights reserved

% Global variables for parameters that are not specified
global daelibinitialized
global daelinewidth
global daelinestyle
global daelinecolor
global daemarkersize
global daecircleresolution

% Define global variables if necessary
if isempty(daelibinitialized),
        initdae;
end

% Set undefined parameters 
if nargin==1,
        linecolor=daelinecolor;
        linestyle=daelinestyle;
        linewidth=daelinewidth;
        markersize=daemarkersize;
else
        if nargin<5 markersize=daemarkersize; end
        if nargin<4 linecolor=daelinecolor; end
        if nargin<3 linestyle=daelinestyle; end
end

c=size(q);
c=c(1,1);

% storage for handles
h=zeros(c,1);

if c==1,
	n=daecircleresolution/2;
	% mult. by 0.999999999 is a ugly way of avoiding  "division by zero"
	g0=[(-1:2/n:1)';1].*0.9999999
	r=-(g0./((g0-1).*(1+q^2)))+sqrt((g0./((g0-1).*(1+q^2))).^2-((-g0-1)./((1-g0).*(1+q^2))));
	xser=q.*r;
	gammat=[ nz2g(r+i*xser) ; flipud(nz2g(r-i*xser)) ];

	h(1,1)=plotc(gammat,linewidth,linestyle,linecolor,markersize);
else
	cc=size(linewidth);
	if cc(1,1)==1, linewidth=ones(c,1)*linewidth; end

	cc=size(linestyle);
	if cc(1,1)==1, linestyle=setstr(ones(c,1)*linestyle); end
	
	cc=size(linecolor);
	if cc(1,1)==1, linecolor=ones(c,1)*linecolor; end

	cc=size(markersize);
	if cc(1,1)==1, markersize=ones(c,1)*markersize; end

	n=daecircleresolution/2
	g0=[(-1:2/n:1)';1].*0.99999999;

	for k=1:c,
		r=-(g0./((g0-1).*(1+q(k,1)^2)))+sqrt((g0./((g0-1).*(1+q(k,1)^2))).^2-((-g0-1)./((1-g0).*(1+q(k,1)^2))));
		xser=q(k,1).*r;
		gammat=[ nz2g(r+i*xser) ; flipud(nz2g(r-i*xser)) ];
		h(k,1)=plotc(gammat,linewidth(k,1),linestyle(k,:),linecolor(k,:),markersize(k,:));
	end

end

drawisoq=h;
