function [drawrlbl]=drawrlbl(r,fontname,fontsize,fontweight,fontangle,fontcolor);
% drawrlbl
% drawrlbl(r,rpos,fontname,fontsize,fontweight,fontangle,fontcolor)
% writes any number of r(resistance)-labels in a Smith-chart.
% If multiple labels are to be written the r-values should appear
% in a column vector: [r1;r2;r3...].
%
% Optional(no column vectors are allowed):
% fontname - ex. 'Helvetica'
% fontsize - in 1/72 inch (points)
% fontweight - ex. 'normal', 'bold'
% fontangle - ex. 'normal', 'italic'
% fontcolor - [R,G,B]
%
% Example:
% drawrlbl([0,0.2,0.5,1,2,5]','Times',10,'bold','italic',[1,1,0]);
% drawrlbl returns a handle to the text objects drawn. In case of
% multiple lables a vertical vector is returned containing the
% handles.

% 1996-10-16 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved


% Global variables for parameters that are not specified
global daelibinitialized
global daefontname
global daefontsize
global daefontweight
global daefontangle
global daefontcolor


% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==1,
	fontcolor=daefontcolor;
	fontangle=daefontangle;
	fontweight=daefontweight;
	fontsize=daefontsize;
	fontname=daefontname;
else
	if nargin<6 fontcolor=daefontcolor; end
	if nargin<5 fontangle=daefontangle; end
	if nargin<4 fontweight=daefontweight; end
	if nargin<3 fontsize=daefontsize; end
end


% Calculate refl. coeff. for the given resistances
gamma=nz2g(r);

hoffset=-0.01;
voffset=i*0.01;
offset=hoffset+voffset;
% Calculate anchor for the lables
pos=offset+gamma;

% Get number of elements
s=size(gamma);
c=s(1,1); % get row count
% storage for handles
h=zeros(c,1);

% loop
for k=1:c,
	if r(k,1)==0
		pos(k,1)=pos(k,1)-2*hoffset;
		h(k,1)=text(real(pos(k,1)),imag(pos(k,1)),...
		'0','HorizontalAlignment',...
		'left','VerticalAlignment','baseline',...
		'Units','data','Clipping','on',...
		'fontname',fontname,'fontsize',fontsize,...
		'fontweight',fontweight,...
		'fontangle',fontangle,...
		'Color',fontcolor);
	else
		h(k,1)=text(real(pos(k,1)),imag(pos(k,1)),...
		num2str(r(k,1)),'HorizontalAlignment',...
		'right','VerticalAlignment','baseline',...
		'Units','data','Clipping','on',...
		'fontname',fontname,'fontsize',fontsize,...
		'fontweight',fontweight,...
		'fontangle',fontangle,...
		'Color',fontcolor);
	end
end

drawrlbl=h;
