function [drawxlbl]=drawxlbl(x,rpos,fontname,fontsize,fontweight,fontangle,fontcolor);
% drawxlbl
% drawxlbl(g,rpos,fontname,fontsize,fontweight,fontangle,fontcolor);
% writes any number of x(reactance)-labels around a Smith-chart.
% If multiple labels are to be written the x-values should appear
% in a column vector: [x1;x2;x3;...].
%
% Optional(no column vectors are allowed):
% rpos - radial position. 1 corresponds to the Smith-chart
% fontname - ex. 'Helvetica'
% fontsize - in 1/72 inch (points)
% fontweight - ex. 'normal', 'bold'
% fontangle - ex. 'normal', 'italic'
% fontcolor - [R,G,B]
%
% Example:
% drawxlbl([0,0.2,0.5,1,2,5]',1.05,'Times',10,'bold','italic',[0,1,1]);
% drawxlbl returns a handle to the text objects drawn. In case of
% multiple lables a vertical vector is returned containing the
% handles.

% 1996-10-20 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved

% Global variables for parameters that are not specified
global daelibinitialized
global daefontname
global daefontsize
global daefontweight
global daefontangle
global daefontcolor


% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==1,
	fontcolor=daefontcolor;
	fontangle=daefontangle;
	fontweight=daefontweight;
	fontsize=daefontsize;
	fontname=daefontname;
	rpos=1.02;
else
	if nargin<7 fontcolor=daefontcolor; end
	if nargin<6 fontangle=daefontangle; end
	if nargin<5 fontweight=daefontweight; end
	if nargin<4 fontsize=daefontsize; end
	if nargin<3 fontname=daefontcolor; end
end


% Calculate refl. coeff. for the given reactances
gamma=nz2g(i*x);

% Calculate anchor for the lables
pos=rpos*gamma;

% Get number of elements
s=size(gamma);
c=s(1,1); % get row count
% storage for handles
h=zeros(c,1);

% loop
for k=1:c,
	if real(gamma(k,1))==0
		if imag(gamma(k,1))>0
			h(k,1)=text(real(pos(k,1)),imag(pos(k,1)),...
			num2str(x(k,1)),'HorizontalAlignment',...
			'center','VerticalAlignment','baseline',...
			'Units','data','Clipping','on',...
			'fontname',fontname,'fontsize',fontsize,...
			'fontweight',fontweight,...
			'fontangle',fontangle,...
			'Color',fontcolor);
		else
			h(k,1)=text(real(pos(k,1)),imag(pos(k,1)),...
			num2str(x(k,1)),'HorizontalAlignment',...
			'center','VerticalAlignment','top',...
			'Units','data','Clipping','on',...
			'fontname',fontname,'fontsize',fontsize,...
			'fontweight',fontweight,...
			'fontangle',fontangle,...
			'Color',fontcolor);
 		end
	elseif real(gamma(k,1))>0
		if imag(gamma(k,1))==0
			h(k,1)=text(real(pos(k,1)),imag(pos(k,1)),...
			num2str(x(k,1)),'HorizontalAlignment',...
			'left','VerticalAlignment','middle',...
			'Units','data','Clipping','on',...
			'fontname',fontname,'fontsize',fontsize,...
			'fontweight',fontweight,...
			'fontangle',fontangle,...
			'Color',fontcolor);
		elseif imag(gamma(k,1))>0
			h(k,1)=text(real(pos(k,1)),imag(pos(k,1)),...
			num2str(x(k,1)),'HorizontalAlignment',...
			'left','VerticalAlignment','baseline',...
			'Units','data','Clipping','on',...
			'fontname',fontname,'fontsize',fontsize,...
			'fontweight',fontweight,...
			'fontangle',fontangle,...
			'Color',fontcolor);
		else
			h(k,1)=text(real(pos(k,1)),imag(pos(k,1)),...
			num2str(x(k,1)),'HorizontalAlignment',...
			'left','VerticalAlignment','top',...
			'Units','data','Clipping','on',...
			'fontname',fontname,'fontsize',fontsize,...
			'fontweight',fontweight,...
			'fontangle',fontangle,...
			'Color',fontcolor);
		end
	else
		if imag(gamma(k,1))==0
			h(k,1)=text(real(pos(k,1)),imag(pos(k,1)),...
			num2str(0),'HorizontalAlignment',...
			'right','VerticalAlignment','middle',...
			'Units','data','Clipping','on',...
			'fontname',fontname,'fontsize',fontsize,...
			'fontweight',fontweight,...
			'fontangle',fontangle,...
			'Color',fontcolor);
		elseif imag(gamma(k,1))>0
			h(k,1)=text(real(pos(k,1)),imag(pos(k,1)),...
			num2str(x(k,1)),'HorizontalAlignment',...
			'right','VerticalAlignment','baseline',...
			'Units','data','Clipping','on',...
			'fontname',fontname,'fontsize',fontsize,...
			'fontweight',fontweight,...
			'fontangle',fontangle,...
			'Color',fontcolor);
		else
			h(k,1)=text(real(pos(k,1)),imag(pos(k,1)),...
			num2str(x(k,1)),'HorizontalAlignment',...
			'right','VerticalAlignment','top',...
			'Units','data','Clipping','on',...
			'fontname',fontname,'fontsize',fontsize,...
			'fontweight',fontweight,...
			'fontangle',fontangle,...
			'Color',fontcolor);
		end
	end
end

drawxlbl=h;

