function [makearc]=makearc(arcspec,n);
% makearc
% makearc(arcspec,n)
% Creates a column of points (complex values) for one arc
% in counterclockwise order. In case of multiple arcspecs
% multiple columns are generated.
% 
%
% Parameters:
% arcspec - [center,radius,startangle,stopangle]
%
% or        [center1,radius1,startangle1,stopangle1;
%            center2,radius2,startangle2,stopangle2... ]
%
%     center - center of circle (complex number)
%     radius - radius of circle
%     startangle - startangle (deg)
%     stopangle - stopangle (deg)
%
% Optional:
% n - number of line segments, uses daecircleresolution
%     to calculate n if n is not specified. n must be scalar.


% 1996-12-18 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996-98. All rights reserved.
%
% 1998-05-21 - added support for column vector of
%              arcspecs so that several arcs can
%              be created in one call.


% Global variables
global daelibinitialized
global daecircleresolution

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

center=arcspec(:,1).';
radius=arcspec(:,2)';
startangle=arcspec(:,3)';
stopangle=arcspec(:,4)';

colcount=length(center);

% Stopangle must always be larger than startangle
stopangle=rem(pi*stopangle/180,2*pi);
startangle=rem(pi*startangle/180,2*pi);

for k=1:colcount,
   while (stopangle(k)<=startangle(k))
      stopangle(k)=stopangle(k)+2*pi;
   end
end

if nargin==1,
	% Number of line segments for a circle
	ncircle=daecircleresolution;
	% Number of line segments for the arc
   n=ceil(ncircle*(stopangle-startangle)/(2*pi));
   n=max(n);
end

narc=n+1;

% Create vector with angles
anglestep=(stopangle-startangle)/n;

anglevector=(0:1:n)'*anglestep+ones(narc,1)*startangle;

anglevector(narc,1:colcount)=stopangle;

makearc=ones(narc,1)*center+(ones(narc,1)*radius).*(cos(anglevector)+i*sin(anglevector));

% end makearc
