function [makebarc]=makebarc(b,gstart,gstop,n);
% makebarc
% makebarc(b,gstart,gstop,n)
% Creates a column of points (complex values) for one susceptance arc
% In case of column vector input multiple columns are generated.
%
% Parameters (scalar or column vectors):
% b - normalized susceptance
% gstart - start conductance
% gstop - stop conductance
%
% Optional:
% n - number of line segments, uses daecircleresolution to
%     calculate n if n is not specified. Must be scalar.

% 1996-12-20 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.
%

% 1998-05-21 - added support for column vector of
%              b,gstart and gstop so that several
%              arcs can be created in one call.


% Global variables
global daelibinitialized
global daecircleresolution

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

center=-1-i./b;
radius=abs(1./b);

colcount=length(b);

swapped=zeros(1,colcount);


for k=1:colcount,
if b(k)>0,
	if gstart(k)>gstop(k),
		tmp=gstart(k);
		gstart(k)=gstop(k);
		gstop(k)=tmp;
		swapped(k)=1;
	end

else
	if gstart(k)<gstop(k),
		tmp=gstart(k);
		gstart(k)=gstop(k);
		gstop(k)=tmp;
		swapped(k)=1;
	end
end

end % for


startangle=180*angle(nz2g(1./(gstart+i*b))-center)/pi;
stopangle=180*angle(nz2g(1./(gstop+i*b))-center)/pi;

if nargin==3,
	h=makearc([center,radius,startangle,stopangle]);
else
	h=makearc([center,radius,startangle,stopangle],n);
end

% Ensure that the order of points corresponds to the direction given
% by gstart, gstop


for k=1:colcount,
	if swapped(k)==1,
		h(:,k)=flipud(h(:,k));
	end
end


makebarc=h;
