function [makegarc]=makegarc(g,bstart,bstop,n);
% makegarc
% makegarc(g,bstart,bstop,n)
% Creates a column of points (complex values) for one conductance arc
% In case of column vector input multiple columns are generated.
%
% Parameters (scalar or column vectors):
% g - normalized conductance
% bstart - start susceptance (drawgarc always draws counterclockwise)
% bstop - stop susceptance
%
% Optional:
% n - number of line segments, uses daecircleresolution to
%     calculate n if n is not specified. Must be scalar.

% 1996-12-20 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.
%

% 1998-05-21 - added support for column vector of
%              g,bstart and bstop so that several
%              arcs can be created in one call.


% Global variables
global daelibinitialized
global daecircleresolution

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

colcount=length(g);


swapped=zeros(1,colcount);


for k=1:colcount
if bstart(k)<bstop(k),
	tmp=bstart(k);
	bstart(k)=bstop(k);
	bstop(k)=tmp;
	swapped(k)=1;
end
end

center=-g./(g+1);
radius=1./(g+1);
startangle=180*angle(nz2g(1./(g+i*bstart))-center)/pi;
stopangle=180*angle(nz2g(1./(g+i*bstop))-center)/pi;

if nargin==3,
	h=makearc([center,radius,startangle,stopangle]);
else
	h=makearc([center,radius,startangle,stopangle],n);
end

% Ensure that the order of points corresponds to the direction given
% by bstart, bstop
for k=1:colcount,
	if swapped(k)==1,
		h(:,k)=flipud(h(:,k));
	end
end


makegarc=h;
