function [makexarc]=makexarc(x,rstart,rstop,n);
% makexarc
% makexarc(x,rstart,rstop)
% Creates a column of points (complex values) for one reactance arc
% In case of column vector input multiple columns are generated.
%
% Parameters (scalar or column vectors):
% x - normalized reactance
% rstart - start resistance
% rstop - stop resistance
%
% Optional:
% n - number of line segments, uses daecircleresolution to
%     calculate n if n is not specified. Must be scalar.

% 1996-12-20 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.
%
% 1998-05-21 - added support for column vector of
%              x,rstart and rstop so that several
%              arcs can be created in one call.


% Global variables
global daelibinitialized
global daecircleresolution

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

center=1+i./x;
radius=abs(1./x);
	
colcount=length(x);

swapped=zeros(1,colcount);

for k=1:colcount,
if x(k)>0,
	if rstart(k)>rstop(k),
		tmp=rstart(k);
		rstart(k)=rstop(k);
		rstop(k)=tmp;
		swapped(k)=1;
	end
else
	if rstart(k)<rstop(k),
		tmp=rstart(k);
		rstart(k)=rstop(k);
		rstop(k)=tmp;
		swapped(k)=1;
	end
end
	
startangle=180*angle(nz2g(rstart+i*x)-center)/pi;
stopangle=180*angle(nz2g(rstop+i*x)-center)/pi;

if nargin==3,
	h=makearc([center,radius,startangle,stopangle]);
else
	h=makearc([center,radius,startangle,stopangle],n);
end

% Ensure that the order of points corresponds to the direction given
% by rstart, rstop
for k=1:colcount,
	if swapped(k)==1,
		h(:,k)=flipud(h(:,k));
	end
end

makexarc=h;
