function [mseffeps]=mseffeps(er,wh);
% mseffeps
% mseffeps(er,wh) calculates the effective relative dielectric
% constant for a microstrip structure given the relative
% dielectric constant of the dielectric substrate (er) and the
% width/height ratio (wh). Several wh-values can be specified
% in a column vector. 
% Reference:  E. Hammersted and O. Jensen,
% "Accurate models for microstrip computer-aided design", 
% In IEEE MTT-S International Microwave Symposium Digest, 1980, pp. 407-409.

% 1997-11-10 Written by Henrik Borjeson,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997. All rights reserved.

% 1999-07-07 Changed to Hammerstad's equations/Lars Sundstrom

u=wh;
eps=ones(length(wh),1);
au=1+(1./49)*log((u.^4+(u./52).^2)./(u.^4+0.432))+(1./18.7).*log(1+(u./18.1).^3);
ber=0.564.*((er-0.9)./(er+3)).^0.053;
ee=(er+1)./2+(er-1)./2.*(1+10./u).^(-au.*ber);

mseffeps=ee;

