function [msz0]=msz0(er,wh);
% msz0
% msz0(er,wh) calculates the characteristic impedance Z0 for a
% microstrip structure given the relative dielectric constant
% of the dielectric substrate (er) and the width/height ratio (wh).
% Several wh-values can be specified in a column vector. 
% Reference:
% E. Hammersted and O. Jensen,
% "Accurate models for microstrip computer-aided design", 
% In IEEE MTT-S International Microwave Symposium Digest, 1980, pp. 407-409.

% 1997-11-10 Written by Henrik Borjeson,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997-1999. All rights reserved.

% 1998-09-11 Fixed a typo in the formula/Lars Sundstrom
% 1999-07-07 Changed to Hammerstad's equations/Lars Sundstrom


% Hammerstad et al

u=wh;
n0=376.73;
fu=6+(2.*pi-6).*exp(-(30.666./u).^0.7528);  
z01=n0./(2*pi).*log(fu./u+sqrt(1+(2./u).^2));
msz0=z01./sqrt(mseffeps(er,wh));

