function [plotc]=plotc(c,linewidth,linestyle,linecolor,markersize);
% plotc
% plotc(c,linewidth,linestyle,linecolor,markersize) plots complex-valued
% points with the real part mapped to the x-axis and the
% imaginary part mapped to the y-axis
%
% Parameters:
% c - complex valued vector to be plotted
%
% Optional:
% linewidth - in 1/72 inch (points)
% linestyle - MATLAB parameter Ex. '-', '-.' etc
% linecolor - [R,G,B]
% markersize - in 1/72 inch (points)

% 1996-12-18 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996. All rights reserved.

% Global variables for parameters that are not specified
global daelibinitialized
global daelinewidth
global daelinestyle
global daelinecolor
global daemarkersize

% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==1,
	linecolor=daelinecolor;
	linestyle=daelinestyle;
	linewidth=daelinewidth;
	markersize=daemarkersize;
else
	if nargin<5 markersize=daemarkersize; end
	if nargin<4 linecolor=daelinecolor; end
	if nargin<3 linestyle=daelinestyle; end
end

plotc=plotxt(real(c),imag(c),linewidth,linestyle,linecolor,markersize);
