function [plotxt]=plotxt(x,y,linewidth,linestyle,linecolor,markersize);
% plotxt
% plotxt((x,y,linewidth,linestyle,linecolor,markersize) is similar
% to plot but it also accepts linewidth, linecolor and markersize
% to be specified.
%
% Parameters:
% x,y - data to be plotted
%
% Optional:
% linewidth - in 1/72 inch (points)
% linestyle - MATLAB parameter Ex. '-', '-.' etc
% linecolor - [R,G,B]
% markersize - in 1/72 inch (points)

% 1996-12-18 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1996-2003. All rights reserved.
% 1997-01-15 Added support for postscript code generation/LSu
% 2003-08-26 Changed handling of linestyle to avoid warning messages/LSu

% Global variables for parameters that are not specified
global daelibinitialized
global daelinewidth
global daelinestyle
global daelinecolor
global daemarkersize
global daepscollectactive


% Define global variables if necessary
if isempty(daelibinitialized),
	initdae;
end

% Set undefined parameters 
if nargin==2,
	linecolor=daelinecolor;
	linestyle=daelinestyle;
	linewidth=daelinewidth;
	markersize=daemarkersize;
else
	if nargin<6 markersize=daemarkersize; end
	if nargin<5 linecolor=daelinecolor; end
	if nargin<4 linestyle=daelinestyle; end
end

% Separate markerstyle from linestyle string
[sepmarkerstyle,seplinestyle]=sepml(linestyle);

h=plot(x,y);
set(h,'LineStyle',seplinestyle,'Marker',sepmarkerstyle,'Linewidth',linewidth,'Color',linecolor,'markersize',markersize);

if daepscollectactive==1,
	psplotxt(x,y,linewidth,linestyle,linecolor,markersize);
end

plotxt=h;
