function [pmr]=pmr(pg,alfa,beta,gammaS,gammaL,length);
% pmr
% pmr(pg,alfa,beta,gammaS,gammaL,length) calculates the delivered
% power over a lossy transmission line from a known source and
% load taking into account the multiple reflection occuring
% due to impedance mismatch at the source and at the load.
% pg - available power from source
% alfa - real part of propagation constant (Neper/m)
% beta - imaginary part of propagation constant
% gammaS - reflection coeff. for source based on Z0 for the transmission line.
% gammaL - reflection coeff. for load based on Z0 for the transmission line.
% length - length of transmission line in metre.

pmr=pg.*exp(-2.*alfa.*length).*(1-abs(gammaS).^2).*(1-abs(gammaL).^2)./(abs(1-gammaS.*gammaL.*exp(-2.*(alfa+i.*beta).*length)).^2);
