function [psbegin]=psbegin(embedfile,targetfile);
% psbegin
% psbegin(embedfile,targetfile)
% begins a postscript collection session
% generated by drawxxx.m(*) functions in daelib.
% The postscript code is stored in the targetfile
% and is embedded by the contents in the embedfile.
% The preceeding and succeeding parts of embedfile
% are separated by a postscript comment line containing
% the string:
%
%  'daelib_code'.
%
% The purpose of the embedfile is to encapsulate the
% postscript code generated with proper headings,
% scaling libraries etc. 
% Two scaling factors must be defined in the embedfile:
%
% /daexscale <scaling factor> def  % horizontal scaling
% /daeyscale <scaling factor> def  % vertical scaling
%
% All coordinates will be multiplied by these factors
% If they are not present in the embedfile a postscript
% error will be generated upon printing.
%
% These scaling factors are used in the postscript code
% to scale coordinates only and not quantities like
% linewidth etc which remain in the standard 1/72
% inch/pixel scale. The reason for doing so
% and not scale everything (which is easily done in
% postscript) is that one can use data coordinates directly
% like in the Smith-chart which has a diameter of 2 that
% covers a whole page which in the original system of
% coordinates corresponds to a length of 600 pixels or so.
% The targetfile is created if necessary.
% A postscript collection session ends with the psend
% functions.
% (*) drawxlbl.m, drawrlbl.m, drawglbl.m, drawblbl.m
% are currently not supported.

% 1997-01-13 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997. All rights reserved.

% 1998-10-06 Removed error handling due to a bug in MATLAB/LSu

% Define global variables
global daeembedfileid
global daetargetfileid
global daepscollectactive

% Open files
[daeembedfileid,message]=fopen(embedfile,'rt');
if ~isempty(message) fprintf('Could not open embedfile.'); return; end

[daetargetfileid,message]=fopen(targetfile,'wt+');
%REMOVED if ~isempty(message) fprintf('Could not open/create targetfile.'); return; end

% Copy first part of embed file to target file

err=0;
daepscollectactive=1;
stringfound=0;

while err==0
   sourcestring=fgets(daeembedfileid);

       	[message,err]=ferror(daeembedfileid);

   	
	if err==0
		if findstr(sourcestring,'daelib_code')
         fprintf(daetargetfileid,'%s\n','% ***daelib postscript code')

         stringfound=1;
			break;
      else

              fprintf(daetargetfileid,'%s',sourcestring);
                   end
	end
end

% if no position found in embed file
if stringfound == 0
	if feof(daeembedfileid)
		fprintf('Warning: end of file reached without',...
		'finding the location for the postscript',...
		'code. Postscript code appended to the end of the file.');
	elseif err~=0
		daepscollectactive=0;
		fprintf(message);
		fprintf('Closing embedfile and targetfile.');
		fclose(daeembedfileid);
		fclose(daetargetfileid);
	end	
else
	% Encapsulate with gsave (and grestore in psend)
	fprintf(daetargetfileid,'%s\n','gsave');
	% Insert postscript scaling function
	fprintf(daetargetfileid,'%s\n','/sc {daexscale mul exch daeyscale mul exch} def');
	% Insert short definition for lineto and moveto
	fprintf(daetargetfileid,'%s\n','/lt {lineto} def');
	fprintf(daetargetfileid,'%s\n','/mt {moveto} def');
end


