function [readspar]=readspar(filename);
% readspar
% readspar(filename) imports S parameters in Touchstone-format.
% Format:
% 1. Any number of comment lines beginning with ! or #
% 2. freq s11 s21 s12 s22 where each parameter is given
%    by its magnitude followed by the argument (in degrees).
% Example (taken from a PHILIPS data file):
%! Filename:       BFG34B.S2P                                 Version:   2.0
%! Philips part #: BFG34                                      Date: Jul 1990
%! Bias condition: Vce=10V, Ic=30mA
%! 
%#  MHz  S  MA  R  50
%! Freq     S11  H11       S21  H21       S12  H12       S22  H22  !GUM [dB]
%   40     .649 -58.6   26.551 150.9    .0240  65.7     .876 -28.6 !    37.2
%  100     .703 -110.   18.267 125.8    .0400  45.4     .624 -55.5 !    30.3
%  200     .734 -144.   10.958 105.7    .0490  33.0     .404 -77.6 !    24.9
%  300     .740 -160.    7.558  95.8    .0530  30.5     .315 -89.9 !    21.5
%
% Comments and other data following the S parameters are ignored.

% 
% Also, note that the frequency columnn will be exactly what is given in

% the file, in other words readspar will not be able to decide whether the unit

% is e.g. MHz or GHz.

% 1994 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1994. All rights reserved.

%

% 1999-09-01 - Updated to allow blanks in the beginning of comment lines.

%              Also changed from isstr(to be removed in future MATLAB versiond)

%              to ischar. 




% Open file
fid=fopen(filename);

% Skip comments
pos=ftell(fid);
ch='#';
while (ch=='#') | (ch=='!'),

	pos=ftell(fid);
	str=fgetl(fid);
	if ~ischar(str),
		break;
   end

   k=1;

   while (str(k)==' '),

      k=k+1;

    end;
	ch=str(k);
end;
fseek(fid,pos,'bof');



imdata=[];

% Read data
error=[];
while isempty(error),
	% Read data from one line
	raw=rot90(fscanf(fid,'%f %f %f %f %f %f %f %f %f',9));
	imdata=[imdata;raw];
	% Skip the comments at the end of the line
	str=fgetl(fid);
	% Save error status (such as EOF) before checking next line
	error=ferror(fid);
	% If next line contains a comment then break loop
	pos=ftell(fid);
	str=fgetl(fid);
	if ~isstr(str),
		break;
	elseif isempty(str),
		break;
	else
		ch=str(1);
		if (ch=='#') | (ch=='!'),
			break;
		else
			fseek(fid,pos,'bof');
		end;
	end;
end;

% Reformat to desired format (polar -> cartesian)
readspar(:,1)=imdata(:,2).*exp(i.*imdata(:,3)*pi/180);
readspar(:,2)=imdata(:,4).*exp(i.*imdata(:,5)*pi/180);
readspar(:,3)=imdata(:,6).*exp(i.*imdata(:,7)*pi/180);
readspar(:,4)=imdata(:,8).*exp(i.*imdata(:,9)*pi/180);
readspar(:,5)=imdata(:,1);

fclose(fid);

