% Functions based on S-parameters
%
% * help <function name> for more information.
%
% Stability
%
%  sdelta     - Delta
%  sk         - K
%
%  sinstci    - Input stability circle ([position,radii])
%  soutstci   - Output stability circle ([position,radii])
%
% Matching
%
%  sgamsmat   - source refl. coeff. for simultaneous conjugate
%               match.
%  sgamlmat   - load refl. coeff. for simultaneous conjugate
%               match.
%
%  sb1, sb2, sc1, c2 - low level routines for sgamsmat and sgamlmat.
%
% Gain, Bilateral
%
%  sga     - available gain
%  sgp     - operating gain
%  sgt     - transducer gain
%  sgp0    - operating gain with gammaS=gammaL=0
%  sgt0    - transducer gain with gammaS=gammaL=0
%  sgtmax  - maximum gain
%  sgmsg   - maximum stable gain gain
%
% Gain, Unilateral
%
%  sgpu    - unilateral operating gain
%  sgtu    - unilateral transducer gain
%  sgtumax - unilateral maximum gain
%
% Circles, Bilateral
%
%  singcib         - available gain circle ([position,radii])
%  soutgcib        - operating gain circle ([position,radii])
%
% Circles, Unilateral
%
%  singciu         - input unilateral gain circle ([position,radii])
%  soutgciu        - output unilateral gain circle ([position,radii])
%
%
% Port Reflection Coefficients for Two-ports
%
%  sgamin    - refl. coeff. for port 1 with given gammal
%  sgamout   - refl. coeff. for port 2 with given gammas
%
%
% Unilateral Figure of Merit
%
%  sufmm    - returns the M factor used to calculate unilateral
%             figure of merit for a two-port with gammmaS=conj(s11)
%             and gammaL=conj(s22).
%  sufmmmm  - returns the minimum and maximum of Gtmax/Gtumax
%             using the unilateral approximation for a two-port
%             with gammmaS=conj(s11) and gammaL=conj(s22).
%  sufmx    - returns the X factor used to calculate unilateral
%             figure of merit for a two-port with arbitrary source and
%             load reflection coefficients ("gammaS" and "gammaL").
%  sufmxmm  - returns the minium and maximum of Gt/Gtu using the
%             unilateral approximation for a two-port with arbitrary
%             source and load reflection coefficients
%             ("gammaS" and "gammaL").

% 1997-01-16 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1997. All rights reserved.
