% Plot gain as a function of frequency
%
% MATLAB script to generate accurate XY-plots for publications etc
% More or less maps properties available through get and set routines.
% Copy this file and fill in your own settings
% After execution of this file use the plot command to plot data.
% 
%
% Copyright (c) 1996-99. All rights reserved.
% Competence Centre for Circuit Design
% Department of Applied Electronics
% Lund University
% P.O Box 118
% 221 00 Lund
% Sweden
%
% Written by Lars Sundstrm, 960624
%
% 990716 - Some updated and correction for MATLAB 5.3

% 2003 Modified by Markus Trmnen,
% Dept of Electroscience, Lund University.
% The script is modified because the function sgamout
% now also returns a frequency component.
% The modification is in the section where output loop gain
% is calculated.

% *** GENERAL SETTINGS ********************************
plotscale=1;			% Scales everything in this script
plotwidth=90;	  		% in mm
plotheight=65;  		% in mm
vertplotoffset=0;		% offset (in mm) from default placement of
horzplotoffset=0;		% plot. In most cases =0.

plotboxvisible='on'		% 'on' or 'off'

plotdeflinewidth=0.5;		% Default line width in pixels


% *** AXES SETTINGS ********************************
% basic
axesvisible='on';		% 'on' or 'off'
axesfontname='Helvetica';	% any available font
axesfontsize=9;			% in pixels
axesfontangle='normal';		% 'normal' or 'italic' or 'oblique'
axesfontweight='normal';	% 'normal' or 'light' or 'demi' or 'bold'

axesgridstyle='-';		% '-' or '--' or ':' or '-.'
axeslinewidth=plotdeflinewidth;	% in pixels

ticklength=0.01;		% Length of ticks relative to plot size
tickdirection='in';		% 'in' or 'out'


% X axis
xdirection='normal';		% 'normal' or 'reverse'
xgrid='off';			% 'on' or 'off'
xlabel='';			% label attached to X axis
xlimits=[0,1];			% [xmin,xmax]
xlimitsmode='auto';		% 'auto' or 'manual'
xscaletype='linear';		% 'linear' or 'log'
xtickmode='auto';		% 'auto' or 'manual'
xtickvalues=[];			% Specify list of values if tickmode='manual'
xticklabelmode='auto';		% 'auto' or 'manual'
xticklabel=[];			% Specify list of labels if
				% xticklabelmode='manual'
xlabelfontname=axesfontname;	% any available font
xlabelfontsize=axesfontsize;	% in pixels
xlabelfontangle=axesfontangle;	% 'normal' or 'italic' or 'oblique'
xlabelfontweight=axesfontweight;% 'normal' or 'light' or 'demi' or 'bold'

% Y axis
ydirection='normal';		% 'normal' or 'reverse'
ygrid='off';			% 'on' or 'off'
ylabel='';			% label attached to Y axis
ylimits=[0,1];			% [ymin,ymax]
ylimitsmode='auto';		% 'auto' or 'manual'
yscaletype='linear';		% 'linear' or 'log'
ytickmode='auto';		% 'auto' or 'manual'
ytickvalues=[];			% Specify list of values if tickmode='manual'
yticklabelmode='auto';		% 'auto' or 'manual'
yticklabel=[];			% Specify list of labels if
				% yticklabelmode='manual'
ylabelfontname=axesfontname;	% any available font
ylabelfontsize=axesfontsize;	% in pixels
ylabelfontangle=axesfontangle;	% 'normal' or 'italic' or 'oblique'
ylabelfontweight=axesfontweight;% 'normal' or 'light' or 'demi' or 'bold'

% *** End of Setup ***********************************


% *** Script to generate plot ************************

% create window
figH=figure;
axesH=gca;

% Scale with plotscale variable
plotdeflinewidth=plotscale*plotdeflinewidth;
axeslinewidth=plotscale*axeslinewidth;
axesfontsize=plotscale*axesfontsize;

% Set figure properties
set(figH,'units','centimeter');

% Set general axes properties
set(axesH,'units','centimeter');
plotrect=get(axesH,'position');
plotrect(1,1)=plotrect(1,1)+plotscale*horzplotoffset;
plotrect(1,2)=plotrect(1,2)+plotscale*vertplotoffset;
plotrect(1,3)=plotscale*plotwidth/10;
plotrect(1,4)=plotscale*plotheight/10;
set(axesH,'box',plotboxvisible);
set(axesH,'position',plotrect);
set(axesH,'visible',axesvisible);
set(axesH,'fontname', axesfontname);
set(axesH,'fontsize', axesfontsize);
set(axesH,'fontangle', axesfontangle);
set(axesH,'fontweight', axesfontweight);
set(axesH,'gridlinestyle', axesgridstyle);
set(axesH,'linewidth', axeslinewidth);
set(axesH,'tickdir', tickdirection);
set(axesH,'ticklength', [ticklength 0.025]);

% X axis
set(axesH,'xdir', xdirection);
set(axesH,'xgrid', xgrid);
xlabelh=text(0,0,xlabel);
set(axesH,'xlabel', xlabelh);
set(xlabelh,'fontname',xlabelfontname);
set(xlabelh,'fontsize',xlabelfontsize);
set(xlabelh,'fontangle',xlabelfontangle);
set(xlabelh,'fontweight',xlabelfontweight);
set(axesH,'xlim', xlimits);
set(axesH,'xlimmode', xlimitsmode);
set(axesH,'xscale', xscaletype);
set(axesH,'xtick', xtickvalues);
set(axesH,'xtickmode', xtickmode);
set(axesH,'xticklabel', xticklabel);
set(axesH,'xticklabelmode', xticklabelmode);

% Y axis
set(axesH,'ydir', ydirection);
set(axesH,'ygrid', ygrid);
ylabelh=text(0,0,ylabel);
set(axesH,'ylabel',ylabelh);
set(ylabelh,'fontname',ylabelfontname);
set(ylabelh,'fontsize',ylabelfontsize);
set(ylabelh,'fontangle',ylabelfontangle);
set(ylabelh,'fontweight',ylabelfontweight);
set(axesH,'ylim', ylimits);
set(axesH,'ylimmode', ylimitsmode);
set(axesH,'yscale', yscaletype);
set(axesH,'ytick', ytickvalues);
set(axesH,'ytickmode', ytickmode);
set(axesH,'yticklabel', yticklabel);
set(axesH,'yticklabelmode', yticklabelmode);

hold on;

% End of script

% begin plotting - EXAMPLE

% BFR520 at 3V, 5mA
%s=readspar('BFR520B.S2P');
s=readspar('bfr520b.s2p');
% 500MHz
s1=s(6,:);
f0=500;

% freq vector
f=s(:,5);

% get vector size
[N,M]=size(f);

% 50 ohm
g0=[zeros(N,1),f];
% short circuit
gshort=[-ones(N,1),f];
% open circuit
gopen=[ones(N,1),f];

% input matching network
gs1=g0;
gstubbs=serline(gshort,0.364,f0);
gs2=parg(gs1,gstubbs);
gs3=serline(gs2,0.306,f0);

%output matching network
gl1=g0;
gstubbl=serline(gshort,0.375,f0);
gl2=parg(gl1,gstubbs);
gl3=serline(gl2,0.261,f0);

% Calculate output loop gain
gamOutTmp=sgamout(s,gs3(:,1));
rtot=real(50*(g2nz(gamOutTmp(:,1))+g2nz(gl3(:,1))));

% plot both with lines and circles
plot(f,rtot);
plot(f,rtot,'o');




