function [ysternkm]=ysternkm(y,GS,GL);
% ysternkm
% ysternkm(y,GS,GL) returns Stern's stability factor K
% for a two-port specified with its y-parameters taking
% into account source and load attenuation ("GS" and "GL")
% to improve stability. Unconditional stability for K>1.
% The two-port is specified with its y-parameters
% (y=[y11,y21,y12,y22]).
% The y-parameters do not need to be normalized.
% But if they are then the conductances, GS and GL,
% should also be normalized.

% 1994 Written by Lars Sundstrom,
% Dept of Appl Electronics, Lund University
% Copyright (c) 1994. All rights reserved.

ysternkm=2.*(real(y(:,1))+GS).*(real(y(:,4))+GL)./(real(y(:,3).*y(:,2))+abs(y(:,3).*y(:,2)));
